AsymmetricKeyPair<B extends PublicKey, V extends PrivateKey> class

A pair of asymmetric keys (a public one and a private one).

Constructors

AsymmetricKeyPair(B publicKey, V privateKey)

Properties

hashCode int
The hash code for this object.
no setterinherited
privateKey → V
final
publicKey → B
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited