CBCBlockCipher class
- Implemented types
Constructors
- CBCBlockCipher(BlockCipher _cipher)
Properties
- algorithmName → String
-
no setteroverride
- blockSize → int
-
The block size of the cipher.
no setteroverride
- forEncryption → bool
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
init(
bool forEncryption, CipherParameters params) → void -
Initialise the cipher for processing.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
processBlock(
Uint8List inp, int inpOff, Uint8List out, int outOff) → int -
Process a block of data.
override
-
reset(
) → void -
Reset the cipher.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited