OpenSshEd25519Converter class

Constructors

OpenSshEd25519Converter()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decodeOpenSshPrivate(Uint8List bytes) → ({String comment, Uint8List publicKey, Uint8List seed})
decodeOpenSshPublicToSpki(String publicKeyLine) Uint8List
encodeOpenSshPrivateBytes({required Uint8List seed, required Uint8List publicKey, String comment = ''}) Uint8List
encodeOpenSshPrivatePem({required Uint8List seed, required Uint8List publicKey, String comment = ''}) String
encodeOpenSshPublicKey(Uint8List publicKey, {String comment = ''}) String
fromOpenSshPrivatePem(String pem) OpenSshEd25519KeyPair
fromPkcs8Spki({required Uint8List pkcs8PrivateKey, Uint8List? spkiPublicKey, String comment = ''}) OpenSshEd25519KeyPair
parseOpenSshPublicKey(String line) → ({String comment, Uint8List publicKeyRaw})