OpenSshEd25519KeyPair class

Constructors

OpenSshEd25519KeyPair({required Uint8List pkcs8PrivateKey, required Uint8List spkiPublicKey, required String opensshPrivateKeyPem, required String opensshPublicKey, required String comment})
const

Properties

comment String
final
hashCode int
The hash code for this object.
no setterinherited
opensshPrivateKeyPem String
final
opensshPublicKey String
final
pkcs8PrivateKey Uint8List
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spkiPublicKey Uint8List
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited