ParametersWithIV<T extends CipherParameters> class
- Inheritance
-
- Object
- CipherParameters
- ParametersWithIV
Constructors
- ParametersWithIV(T parameters, Uint8List iv)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- iv → Uint8List
-
final
- parameters → T
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited