RsaPkcs1v15 class

Utility for RSA PKCS#1 v1.5 sign/verify using platform hashing.

Constructors

RsaPkcs1v15()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

buildDigestInfo(Uint8List digest, {String? digestOid}) Uint8List
buildDigestInfoFromData(Uint8List data, {String? digestOid}) Uint8List
digestForOid(Uint8List data, String? digestOid) Uint8List
normalizeDigestOid(String? digestOid) String
signData({required RSAPrivateKey privateKey, required Uint8List data, String? digestOid}) Uint8List
signDigest({required RSAPrivateKey privateKey, required Uint8List digest, String? digestOid}) Uint8List
verifyData({required RSAPublicKey publicKey, required Uint8List data, required Uint8List signature, String? digestOid}) bool
verifyDigest({required RSAPublicKey publicKey, required Uint8List digest, required Uint8List signature, String? digestOid}) bool

Constants

sha1Oid → const String
sha256Oid → const String
sha384Oid → const String
sha512Oid → const String