SecureRandom class abstract
The interface for secure random number generators.
- Implemented types
Constructors
- SecureRandom(String algorithmName)
-
factory
Properties
- algorithmName → String
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
nextBigInteger(
int bitLength) → BigInt -
nextBytes(
int count) → Uint8List -
nextUint8(
) → int -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
seed(
CipherParameters params) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited