SignatureAdapter class
Adapter único para assinatura/verificação assimétrica.
- RSA PKCS#1 v1.5 via engine interno.
- ECDSA/Ed25519 via PlatformCrypto (Web Crypto no browser).
Constructors
- SignatureAdapter({PlatformCrypto? crypto})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
ecdsaSignDer(
{required String namedCurve, required String hashAlgorithm, required Uint8List pkcs8PrivateKey, required Uint8List data}) → Future< Uint8List> -
ecdsaVerifyDer(
{required String namedCurve, required String hashAlgorithm, required Uint8List spkiPublicKey, required Uint8List data, required Uint8List derSignature}) → Future< bool> -
ed25519Sign(
{required Uint8List pkcs8PrivateKey, required Uint8List data}) → Future< Uint8List> -
ed25519Verify(
{required Uint8List spkiPublicKey, required Uint8List data, required Uint8List signature}) → Future< bool> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rsaPkcs1v15SignData(
{required RSAPrivateKey privateKey, required Uint8List data, String? digestOid}) → Uint8List -
rsaPkcs1v15SignDigest(
{required RSAPrivateKey privateKey, required Uint8List digest, String? digestOid}) → Uint8List -
rsaPkcs1v15SignPkcs8(
{required String hashAlgorithm, required Uint8List pkcs8PrivateKey, required Uint8List data}) → Future< Uint8List> -
rsaPkcs1v15VerifyData(
{required RSAPublicKey publicKey, required Uint8List data, required Uint8List signature, String? digestOid}) → bool -
rsaPkcs1v15VerifyDigest(
{required RSAPublicKey publicKey, required Uint8List digest, required Uint8List signature, String? digestOid}) → bool -
rsaPkcs1v15VerifySpki(
{required String hashAlgorithm, required Uint8List spkiPublicKey, required Uint8List data, required Uint8List signature}) → Future< bool> -
rsaPssSignPkcs8(
{required String hashAlgorithm, required Uint8List pkcs8PrivateKey, required Uint8List data, int saltLength = 32}) → Future< Uint8List> -
rsaPssVerifySpki(
{required String hashAlgorithm, required Uint8List spkiPublicKey, required Uint8List data, required Uint8List signature, int saltLength = 32}) → Future< bool> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
curveCoordinateLength(
String namedCurve) → int -
ecdsaDerToRaw(
Uint8List derSignature, {required String namedCurve}) → Uint8List -
ecdsaRawToDer(
Uint8List rawSignature, {required String namedCurve}) → Uint8List