Signer class abstract

The interface for signers.

Implemented types

Constructors

Signer(String algorithmName)
factory

Properties

algorithmName String
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

generateSignature(Uint8List message) Signature
Generates a signature for the given message.
init(bool forSigning, CipherParameters params) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset() → void
toString() String
A string representation of this object.
inherited
verifySignature(Uint8List message, Signature signature) bool
Verifies the given signature against the given message.

Operators

operator ==(Object other) bool
The equality operator.
inherited