pdf library

Classes

PdfaAttachedFiles
PdfaColorProfile
PdfaFacturxRdf
PdfAnnot
Annotation object wrapper attached to a page.
PdfAnnotBase
Base class for PDF annotations.
PdfAnnotCircle
Circle annotation.
PdfAnnotInk
Ink list annotation.
Named destination link annotation.
PdfAnnotPolygon
Polygon/polyline annotation.
PdfAnnotSign
Signature widget annotation.
PdfAnnotSquare
Square annotation.
PdfAnnotText
Text annotation.
URL link annotation.
PdfAnnotWidget
Base class for widget annotations (AcroForm).
PdfaRdf
PdfBaseFunction
PdfBorder
Defines a border object
PdfButtonField
Button field widget.
PdfCachedRandomAccessReader
Cache LRU por blocos para leitura randômica.
PdfChoiceField
Choice field widget (combo/list).
PdfColor
Represents an RGB color.
PdfColorCmyk
Represents a CMYK color.
PdfColorGrey
PdfColorHsl
Represents an HSL color.
PdfColorHsv
Same as HSB: cylindrical geometry with hue and angular dimension, starting at the red primary at 0°, passing through the green primary at 120° and the blue primary at 240°, and then wrapping back to red at 360°
PdfColors
Material design colors.
PdfDocument
Core PDF document model used to create and serialize PDF files.
PdfDocumentParserBase
Base class for loading an existing PDF document.
PdfEncryption
Encryption object
PdfFont
Pdf font object
PdfFontMetrics
Describe dimensions for glyphs in a font
PdfFormField
Base class for AcroForm fields.
PdfFunction
PdfGraphics
Pdf drawing operations
PdfGraphicState
Graphic state configuration for opacity and blending.
PdfGraphicStates
Stores all graphic states used in the document.
PdfImage
Image object stored in the Pdf document
PdfInfo
Information object
PdfJpegInfo
JPEG metadata extraction.
PdfMemoryRandomAccessReader
Implementação em memória (web e uso simples no VM).
PdfMetadata
Pdf Metadata
PdfName
PdfNameTokens
PDF name tokens used throughout the library.
PdfOutline
Pdf Outline object
PdfPage
Page object that holds all contents for a page.
PdfPageFormat
Describes a page size and margins in PDF points.
PdfPageLabel
PdfPageLabels
Pdf PageLabels object
PdfPattern
PdfPoint
Immutable point in PDF user space.
PdfRandomAccessReader
Leitor randômico síncrono para PDF.
PdfRasterBase
Represents a bitmap image.
PdfRect
Immutable rectangle in PDF user space.
PdfSecurityInspectionResult
PdfSecurityInspector
PdfShading
PdfShadingPattern
PdfSignature
PdfSignatureBase
PdfSignatureFieldEditor
PdfSignatureTools
Convenience helpers for external signing workflows.
PdfSize
Immutable size with width and height.
PdfSoftMask
PdfStitchingFunction
PdfTextField
Text field widget.
PdfTtfFont
PdfUriAnnotation
Convenience wrapper for URL annotations.
TtfBitmapInfo
TtfGlyphInfo
TtfParser

Enums

PdfAnnotAppearance
Annotation appearance states.
PdfAnnotFlags
Annotation behavior flags.
PdfAnnotHighlighting
Highlighting modes for widget annotations.
PdfBlendMode
Blend modes for compositing operations.
PdfBorderStyle
Border style
PdfExifTag
Possible Exif tags
PdfFieldFlags
AcroForm field flags.
PdfImageOrientation
Represents the position of the first pixel in the data stream This corresponds to the exif orientations
PdfLineCap
Specify the shape that shall be used at the ends of open sub paths and dashes, when they are stroked.
PdfLineJoin
Shape to be used at the corners of paths that are stroked
PdfOutlineMode
Outline mode
PdfOutlineStyle
Outline style
PdfPageLabelStyle
PdfPageMode
Display hint for the PDF viewer.
PdfPageRotation
Page rotation.
PdfShadingType
PdfSigFlags
Signature flags
PdfTextFieldAlign
Text alignment for text fields.
PdfTextRenderingMode
Text rendering mode
PdfVersion
PDF version to generate
TtfParserName

Typedefs

DeflateCallback = List<int> Function(List<int> data)
Callback used to compress the data