PdfAnnotBase class abstract

Base class for PDF annotations.

Implementers

Constructors

PdfAnnotBase({required String subtype, required PdfRect rect, PdfBorder? border, String? content, String? name, Set<PdfAnnotFlags>? flags, DateTime? date, PdfColor? color, String? subject, String? author})
Creates an annotation base.

Properties

author String?
The author of the annotation.
final
border PdfBorder?
Border for this annotation.
final
color PdfColor?
Annotation color.
final
content String?
Text content of the annotation.
final
date DateTime?
Last modification date.
final
flags Set<PdfAnnotFlags>
Flags specifying various characteristics of the annotation.
latefinal
flagValue int
Encoded annotation flags value.
no setter
hashCode int
The hash code for this object.
no setterinherited
name String?
Internal name for a link.
final
rect PdfRect
Annotation rectangle.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subject String?
The subject of the annotation.
final
subtype String
The annotation subtype.
final

Methods

appearance(PdfDocument pdfDocument, PdfAnnotAppearance type, {String? name, Matrix4? matrix, PdfRect? boundingBox, bool selected = false}) PdfGraphics
Creates and registers a form XObject for the appearance stream.
build(PdfPage page, PdfObject<PdfDataType> object, PdfDict<PdfDataType> params) → void
Writes the annotation dictionary entries.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited