PdfAnnotUrlLink class

URL link annotation.

Inheritance
Implementers

Constructors

PdfAnnotUrlLink({required PdfRect rect, required String url, PdfBorder? border, Set<PdfAnnotFlags>? flags, DateTime? date, PdfColor? color, String? subject, String? author})
Creates a URL link annotation.

Properties

author String?
The author of the annotation.
finalinherited
border PdfBorder?
Border for this annotation.
finalinherited
color PdfColor?
Annotation color.
finalinherited
content String?
Text content of the annotation.
finalinherited
date DateTime?
Last modification date.
finalinherited
flags Set<PdfAnnotFlags>
Flags specifying various characteristics of the annotation.
latefinalinherited
flagValue int
Encoded annotation flags value.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
name String?
Internal name for a link.
finalinherited
rect PdfRect
Annotation rectangle.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subject String?
The subject of the annotation.
finalinherited
subtype String
The annotation subtype.
finalinherited
url String
Target URL.
final

Methods

appearance(PdfDocument pdfDocument, PdfAnnotAppearance type, {String? name, Matrix4? matrix, PdfRect? boundingBox, bool selected = false}) PdfGraphics
Creates and registers a form XObject for the appearance stream.
inherited
build(PdfPage page, PdfObject<PdfDataType> object, PdfDict<PdfDataType> params) → void
Writes the URI action.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited