PdfButtonField class

Button field widget.

Inheritance

Constructors

PdfButtonField({required PdfRect rect, required String fieldName, String? alternateName, String? mappingName, PdfBorder? border, Set<PdfAnnotFlags>? flags, DateTime? date, PdfColor? color, PdfColor? backgroundColor, PdfAnnotHighlighting? highlighting, Set<PdfFieldFlags>? fieldFlags, String? value, String? defaultValue})
Creates a button field widget.

Properties

alternateName String?
Alternate field name.
finalinherited
author String?
The author of the annotation.
finalinherited
backgroundColor PdfColor?
Background color.
finalinherited
border PdfBorder?
Border for this annotation.
finalinherited
color PdfColor?
Annotation color.
finalinherited
content String?
Text content of the annotation.
finalinherited
date DateTime?
Last modification date.
finalinherited
defaultValue String?
Default value.
final
fieldFlags Set<PdfFieldFlags>?
Field flags.
finalinherited
fieldFlagsValue int
Encoded field flags value.
no setterinherited
fieldName String?
Field name.
finalinherited
fieldType String
Field type name.
finalinherited
flags Set<PdfAnnotFlags>
Flags specifying various characteristics of the annotation.
latefinalinherited
flagValue int
Encoded annotation flags value.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
highlighting PdfAnnotHighlighting?
Highlighting behavior.
finalinherited
mappingName String?
Mapping name.
finalinherited
name String?
Internal name for a link.
finalinherited
rect PdfRect
Annotation rectangle.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subject String?
The subject of the annotation.
finalinherited
subtype String
The annotation subtype.
finalinherited
value String?
Current value.
final

Methods

appearance(PdfDocument pdfDocument, PdfAnnotAppearance type, {String? name, Matrix4? matrix, PdfRect? boundingBox, bool selected = false}) PdfGraphics
Creates and registers a form XObject for the appearance stream.
inherited
build(PdfPage page, PdfObject<PdfDataType> object, PdfDict<PdfDataType> params) → void
Writes button field parameters.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited