PdfCachedRandomAccessReader class

Cache LRU por blocos para leitura randômica.

Implemented types

Constructors

PdfCachedRandomAccessReader(PdfRandomAccessReader _inner, {int blockSize = 256 * 1024, int maxBlocks = 32})

Properties

blockSize int
final
hashCode int
The hash code for this object.
no setterinherited
length int
no setteroverride
maxBlocks int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readAll() Uint8List
override
readRange(int offset, int length) Uint8List
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited