PdfChoiceField class

Choice field widget (combo/list).

Inheritance

Constructors

PdfChoiceField({required PdfRect rect, required PdfColor textColor, required PdfFont font, required double fontSize, required List<String> items, String? fieldName, String? value, String? defaultValue})
Creates a choice field widget.

Properties

author String?
The author of the annotation.
finalinherited
backgroundColor PdfColor?
Background color.
finalinherited
border PdfBorder?
Border for this annotation.
finalinherited
color PdfColor?
Annotation color.
finalinherited
content String?
Text content of the annotation.
finalinherited
date DateTime?
Last modification date.
finalinherited
defaultValue String?
Default value.
final
fieldFlags Set<PdfFieldFlags>?
final
fieldFlagsValue int
Encoded field flags value.
no setter
fieldName String?
Field name.
finalinherited
fieldType String
Field type name.
finalinherited
flags Set<PdfAnnotFlags>
Flags specifying various characteristics of the annotation.
latefinalinherited
flagValue int
Encoded annotation flags value.
no setterinherited
font PdfFont
Font used to draw the value.
final
fontSize double
Font size used to draw the value.
final
hashCode int
The hash code for this object.
no setterinherited
highlighting PdfAnnotHighlighting?
Highlighting behavior.
finalinherited
items List<String>
Option items.
final
name String?
Internal name for a link.
finalinherited
rect PdfRect
Annotation rectangle.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subject String?
The subject of the annotation.
finalinherited
subtype String
The annotation subtype.
finalinherited
textColor PdfColor
Text color for the appearance.
final
value String?
Current value.
final

Methods

appearance(PdfDocument pdfDocument, PdfAnnotAppearance type, {String? name, Matrix4? matrix, PdfRect? boundingBox, bool selected = false}) PdfGraphics
Creates and registers a form XObject for the appearance stream.
inherited
build(PdfPage page, PdfObject<PdfDataType> object, PdfDict<PdfDataType> params) → void
Writes the widget appearance and field parameters.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited