PdfColorGrey class

Inheritance

Constructors

PdfColorGrey(double color, [double alpha = 1.0])
Creates a grey color.
const

Properties

alpha double
Opacity component.
finalinherited
analagous List<PdfColor>
Returns analogous colors.
no setterinherited
blue double
Blue component.
finalinherited
complementary PdfColor
Returns a complementary color with hue shifted by -120°.
no setterinherited
green double
Green component.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
isDark bool
Determines whether the given PdfColor is dark.
no setterinherited
isLight bool
Determines whether the given PdfColor is light.
no setterinherited
luminance double
Returns the relative luminance.
no setterinherited
monochromatic List<PdfColor>
Returns similar colors.
no setterinherited
red double
Red component.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
splitcomplementary List<PdfColor>
Returns complementary colors.
no setterinherited
tetradic List<PdfColor>
Returns tetradic colors.
no setterinherited
triadic List<PdfColor>
Returns triadic colors.
no setterinherited

Methods

flatten({PdfColor background = const PdfColor(1, 1, 1)}) PdfColor
Apply the color transparency by updating the color values according to a background color.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shade(double strength) PdfColor
Build a Material Color shade using the given strength.
inherited
toCmyk() PdfColorCmyk
Converts this color to CMYK.
inherited
toHex() String
Returns a hexadecimal representation (#RRGGBBAA).
inherited
toHsl() PdfColorHsl
Converts this color to HSL.
inherited
toHsv() PdfColorHsv
Converts this color to HSV.
inherited
toInt() int
Returns the 32-bit integer representation (0xAARRGGBB).
inherited
toString() String
A string representation of this object.
inherited
withAlpha(double alpha) PdfColor
Returns a copy with a different alpha value.
inherited
withBlue(double blue) PdfColor
Returns a copy with a different blue value.
inherited
withGreen(double green) PdfColor
Returns a copy with a different green value.
inherited
withRed(double red) PdfColor
Returns a copy with a different red value.
inherited
withValues(double? alpha, double? red, double? green, double? blue) PdfColor
Returns a copy with different component values.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited