PdfColorHsl class

Represents an HSL color.

Inheritance

Constructors

PdfColorHsl(double hue, double saturation, double lightness, [double alpha = 1.0])
Creates an HSL color.
factory
PdfColorHsl.fromRgb(double red, double green, double blue, [double alpha = 1.0])
Creates an HSL color from RGB components.
factory

Properties

alpha double
Opacity component.
finalinherited
analagous List<PdfColor>
Returns analogous colors.
no setterinherited
blue double
Blue component.
finalinherited
complementary PdfColor
Returns a complementary color with hue shifted by -120°.
no setterinherited
green double
Green component.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
hue double
Hue component.
final
isDark bool
Determines whether the given PdfColor is dark.
no setterinherited
isLight bool
Determines whether the given PdfColor is light.
no setterinherited
lightness double
Lightness component.
final
luminance double
Returns the relative luminance.
no setterinherited
monochromatic List<PdfColor>
Returns similar colors.
no setterinherited
red double
Red component.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
saturation double
Saturation component.
final
splitcomplementary List<PdfColor>
Returns complementary colors.
no setterinherited
tetradic List<PdfColor>
Returns tetradic colors.
no setterinherited
triadic List<PdfColor>
Returns triadic colors.
no setterinherited

Methods

flatten({PdfColor background = const PdfColor(1, 1, 1)}) PdfColor
Apply the color transparency by updating the color values according to a background color.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shade(double strength) PdfColor
Build a Material Color shade using the given strength.
inherited
toCmyk() PdfColorCmyk
Converts this color to CMYK.
inherited
toHex() String
Returns a hexadecimal representation (#RRGGBBAA).
inherited
toHsl() PdfColorHsl
Converts this color to HSL.
override
toHsv() PdfColorHsv
Converts this color to HSV.
inherited
toInt() int
Returns the 32-bit integer representation (0xAARRGGBB).
inherited
toString() String
A string representation of this object.
override
withAlpha(double alpha) PdfColor
Returns a copy with a different alpha value.
inherited
withBlue(double blue) PdfColor
Returns a copy with a different blue value.
inherited
withGreen(double green) PdfColor
Returns a copy with a different green value.
inherited
withHue(double hue) PdfColorHsl
Returns a copy with a different hue value.
withLightness(double lightness) PdfColorHsl
Returns a copy with a different lightness value.
withRed(double red) PdfColor
Returns a copy with a different red value.
inherited
withSaturation(double saturation) PdfColorHsl
Returns a copy with a different saturation value.
withValues(double? alpha, double? red, double? green, double? blue) PdfColor
Returns a copy with different component values.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited