PdfColorHsv class

Same as HSB: cylindrical geometry with hue and angular dimension, starting at the red primary at 0°, passing through the green primary at 120° and the blue primary at 240°, and then wrapping back to red at 360°

Inheritance

Constructors

PdfColorHsv(double hue, double saturation, double value, [double alpha = 1.0])
Creates an HSV color.
factory
PdfColorHsv.fromRgb(double red, double green, double blue, [double alpha = 1.0])
Creates an HSV color from RGB components.
factory

Properties

alpha double
Opacity component.
finalinherited
analagous List<PdfColorHsv>
Returns analogous colors.
no setteroverride
blue double
Blue component.
finalinherited
complementary PdfColorHsv
Returns a complementary color with hue shifted by -120°.
no setteroverride
green double
Green component.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
hue double
Hue in degrees from 0° to 360°.
final
isDark bool
Determines whether the given PdfColor is dark.
no setterinherited
isLight bool
Determines whether the given PdfColor is light.
no setterinherited
luminance double
Returns the relative luminance.
no setterinherited
monochromatic List<PdfColorHsv>
Returns a list of similar colors.
no setteroverride
red double
Red component.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
saturation double
Saturation of the color.
final
splitcomplementary List<PdfColorHsv>
Returns two complementary colors.
no setteroverride
tetradic List<PdfColorHsv>
Returns tetradic colors.
no setteroverride
triadic List<PdfColorHsv>
Returns triadic colors.
no setteroverride
value double
Brightness (value).
final

Methods

flatten({PdfColor background = const PdfColor(1, 1, 1)}) PdfColor
Apply the color transparency by updating the color values according to a background color.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shade(double strength) PdfColor
Build a Material Color shade using the given strength.
inherited
toCmyk() PdfColorCmyk
Converts this color to CMYK.
inherited
toHex() String
Returns a hexadecimal representation (#RRGGBBAA).
inherited
toHsl() PdfColorHsl
Converts this color to HSL.
inherited
toHsv() PdfColorHsv
Converts this color to HSV.
override
toInt() int
Returns the 32-bit integer representation (0xAARRGGBB).
inherited
toString() String
A string representation of this object.
override
withAlpha(double alpha) PdfColor
Returns a copy with a different alpha value.
inherited
withBlue(double blue) PdfColor
Returns a copy with a different blue value.
inherited
withGreen(double green) PdfColor
Returns a copy with a different green value.
inherited
withHue(double hue) PdfColorHsv
Returns a copy with a different hue value.
withRed(double red) PdfColor
Returns a copy with a different red value.
inherited
withSaturation(double saturation) PdfColorHsv
Returns a copy with a different saturation value.
withValue(double value) PdfColorHsv
Returns a copy with a different brightness value.
withValues(double? alpha, double? red, double? green, double? blue) PdfColor
Returns a copy with different component values.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited