PdfDocumentParserBase class abstract

Base class for loading an existing PDF document.

Implementers

Constructors

PdfDocumentParserBase(PdfRandomAccessReader reader, {bool enableCache = true, int cacheBlockSize = 256 * 1024, int cacheMaxBlocks = 32})
Creates a document loader instance.
PdfDocumentParserBase.fromBytes(Uint8List bytes, {bool enableCache = true, int cacheBlockSize = 256 * 1024, int cacheMaxBlocks = 32})
Creates a document loader instance from bytes.

Properties

bytes Uint8List
The existing PDF document content.
no setter
hashCode int
The hash code for this object.
no setterinherited
reader PdfRandomAccessReader
Random access reader.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
The objects size of the existing PDF document.
no setter
version PdfVersion
The PDF version of the parsed document.
no setter
xrefOffset int
The offset of the previous cross reference table.
no setter

Methods

extractSignatureFieldEditContext() PdfSignatureFieldEditContext
Extracts the signature field edit context, if any.
mergeDocument(PdfDocument pdfDocument) → void
Imports the existing objects into the new PDF document.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited