PdfPage class

Page object that holds all contents for a page.

Constructors

PdfPage(PdfDocument pdfDocument, {PdfPageFormat pageFormat = PdfPageFormat.standard, PdfPageRotation rotate = PdfPageRotation.none, int? index, int? objser, int objgen = 0})
Creates a page and registers it in the document page list.

Properties

altered bool
getter/setter pairinherited
annotations List<PdfAnnot>
Annotations contained within this page.
final
contents List<PdfObject<PdfDataType>>
Content streams for the page.
final
elapsedStopwatch int
no setterinherited
fonts Map<String, PdfFont>
The fonts associated with this page
finalinherited
hashCode int
The hash code for this object.
no setterinherited
inUse bool
getter/setter pairinherited
isolatedTransparency bool
Isolated transparency: If this flag is true, objects within the group shall be composited against a fully transparent initial backdrop; if false, they shall be composited against the group’s backdrop
getter/setter pairinherited
knockoutTransparency bool
Whether the transparency group is a knockout group. If this flag is false, later objects within the group shall be composited with earlier ones with which they overlap; if true, they shall be composited with the group’s initial backdrop and shall overwrite any earlier overlapping objects.
getter/setter pairinherited
objgen int
This is the generation number for this object.
finalinherited
objser int
This is the unique serial number for this object.
finalinherited
pageFormat PdfPageFormat
Page format (size and margins).
getter/setter pair
params → PdfDict<PdfDataType>
finalinherited
patterns Map<String, PdfPattern>
The shaders associated with this page
finalinherited
pdfDocument PdfDocument
This allows any Pdf object to refer to the document being constructed.
finalinherited
rotate PdfPageRotation
The page rotation.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
settings → PdfSettings
finalinherited
shading Map<String, PdfShading>
The shaders associated with this page
finalinherited
size int
getter/setter pairinherited
xObjects Map<String, PdfXObject>
The xobjects or other images in the pdf
finalinherited

Methods

addAnnotation(PdfAnnot ob) → void
Adds an annotation to the page.
addFont(PdfFont font) → void
Add a font to this graphic object
inherited
addPattern(PdfPattern pattern) → void
Add a pattern to this graphic object
inherited
addShader(PdfShading shader) → void
Add a shader to this graphic object
inherited
addXObject(PdfXObject object) → void
Add an XObject to this graphic object
inherited
debugFill(String value) → void
inherited
getDefaultFont() PdfFont?
Get the default font of this graphic object
inherited
getGraphics() PdfGraphics
Returns a PdfGraphics object for drawing on this page.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
output(PdfStream s) int
inherited
prepare() → void
Prepare the object to be written to the stream
ref() → PdfIndirect
Returns the unique serial number in Pdf format
inherited
setInsertion(PdfStream os, [int size = _maxSize]) → void
inherited
startStopwatch() → void
inherited
stateName(PdfGraphicState state) String
Generate a name for the graphic state object
inherited
stopStopwatch() → void
inherited
toString() String
A string representation of this object.
inherited
writeContent(PdfStream s) → void
inherited
writeDebug(PdfStream os) → void
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited