PdfPageFormat class

Describes a page size and margins in PDF points.

Constructors

PdfPageFormat(double width, double height, {double marginTop = 0.0, double marginBottom = 0.0, double marginLeft = 0.0, double marginRight = 0.0, double? marginAll})
Creates a page format with optional margins.
const

Properties

availableDimension PdfPoint
Total page dimensions excluding margins.
no setter
availableHeight double
Total page height excluding margins.
no setter
availableWidth double
Total page width excluding margins.
no setter
dimension PdfPoint
Total page dimensions.
no setter
hashCode int
The hash code for this object.
no setteroverride
height double
Page height in points.
final
landscape PdfPageFormat
Landscape orientation variant.
no setter
marginBottom double
Bottom margin in points.
final
marginLeft double
Left margin in points.
final
marginRight double
Right margin in points.
final
marginTop double
Top margin in points.
final
portrait PdfPageFormat
Portrait orientation variant.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width double
Page width in points.
final

Methods

applyMargin({required double left, required double top, required double right, required double bottom}) PdfPageFormat
Applies minimum margins to this format.
copyWith({double? width, double? height, double? marginTop, double? marginBottom, double? marginLeft, double? marginRight}) PdfPageFormat
Returns a copy with updated values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

a3 → const PdfPageFormat
A3 page format with default margins.
a4 → const PdfPageFormat
A4 page format with default margins.
a5 → const PdfPageFormat
A5 page format with default margins.
a6 → const PdfPageFormat
A6 page format with default margins.
cm → const double
Centimeters in points.
dp → const double
Flutter's Logical Pixel
inch → const double
Inches in points.
US Legal page format with default margins.
letter → const PdfPageFormat
US Letter page format with default margins.
mm → const double
Millimeters in points.
point → const double
PDF point unit.
roll57 → const PdfPageFormat
57mm roll format with default margins.
roll80 → const PdfPageFormat
80mm roll format with default margins.
standard → const PdfPageFormat
Standard page format alias (A4).
undefined → const PdfPageFormat
Undefined page format (infinite size).