PdfPoint class

Immutable point in PDF user space.

Annotations
  • @immutable

Constructors

PdfPoint(double x, double y)
Creates a point at x, y.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
x double
X coordinate.
final
y double
X coordinate.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override
translate(double offsetX, double offsetY) PdfPoint
Returns a translated point.

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

zero → const PdfPoint
The origin point.