PdfRandomAccessReader class abstract

Leitor randômico síncrono para PDF.

Implementers

Constructors

PdfRandomAccessReader()

Properties

hashCode int
The hash code for this object.
no setterinherited
length int
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readAll() Uint8List
readRange(int offset, int length) Uint8List
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited