PdfRasterBase class

Represents a bitmap image.

Constructors

PdfRasterBase(int width, int height, bool alpha, Uint8List pixels)
Creates a bitmap image container.
const
PdfRasterBase.fromImage(Image image)
Creates a raster from a decoded im.Image.
factory
PdfRasterBase.fromPng(Uint8List png)
Creates a raster from PNG bytes.
factory

Properties

alpha bool
Whether the alpha channel is used.
final
hashCode int
The hash code for this object.
no setterinherited
height int
The height of the image.
final
pixels Uint8List
The raw RGBA pixels of the image.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width int
The width of the image.
final

Methods

asImage() → Image
Returns the image as an im.Image object.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toPng() Future<Uint8List>
Encodes this raster as a PNG image.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

shadowEllipse(double width, double height, double spreadRadius, double blurRadius, PdfColor color) → Image
Builds a blurred elliptical shadow image.
shadowRect(double width, double height, double spreadRadius, double blurRadius, PdfColor color) → Image
Builds a blurred rectangular shadow image.