PdfRect.fromLBRT constructor
Creates a rectangle from left, bottom, right and top.
Implementation
factory PdfRect.fromLBRT(
double left, double bottom, double right, double top) {
return PdfRect(left, bottom, right - left, top - bottom);
}
Creates a rectangle from left, bottom, right and top.
factory PdfRect.fromLBRT(
double left, double bottom, double right, double top) {
return PdfRect(left, bottom, right - left, top - bottom);
}