PdfSecurityInspectionResult class

Constructors

PdfSecurityInspectionResult({required bool isPdf, required bool isEncrypted, required bool isSigned, required bool isCorrupted, required int signatureCount, required double pdfVersion, required int startXref, required bool hasEofMarker, required bool hasValidByteRanges, required List<String> issues, required List<String> subFilters, required bool supportedSubFilters, bool? allSignaturesIntact, String? sha256Hex})
const

Properties

allSignaturesIntact bool?
final
hasEofMarker bool
final
hashCode int
The hash code for this object.
no setterinherited
hasValidByteRanges bool
final
isCorrupted bool
final
isEncrypted bool
final
isPdf bool
final
isSigned bool
final
issues List<String>
final
pdfVersion double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sha256Hex String?
final
signatureCount int
final
startXref int
final
subFilters List<String>
final
supportedSubFilters bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited