PdfSecurityInspector class
Constructors
- PdfSecurityInspector({PlatformCrypto? crypto})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
inspect(
Uint8List pdfBytes, {bool validateSignatures = false, bool includeSha256 = false}) → Future< PdfSecurityInspectionResult> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
quickInspect(
Uint8List pdfBytes) → PdfSecurityInspectionResult -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited