PdfSize class

Immutable size with width and height.

Annotations
  • @immutable

Constructors

PdfSize(double width, double height)
Creates a size with width and height.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
height double
Height component.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width double
Width component.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toPoint() PdfPoint
Converts this size to a point.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited