PdfTextField class

Text field widget.

Inheritance

Constructors

PdfTextField({required PdfRect rect, String? fieldName, String? alternateName, String? mappingName, PdfBorder? border, Set<PdfAnnotFlags>? flags, DateTime? date, String? subject, String? author, PdfColor? color, PdfColor? backgroundColor, PdfAnnotHighlighting? highlighting, Set<PdfFieldFlags>? fieldFlags, String? value, String? defaultValue, int? maxLength, required PdfFont font, required double fontSize, required PdfColor textColor, PdfTextFieldAlign? textAlign})
Creates a text field widget.

Properties

alternateName String?
Alternate field name.
finalinherited
author String?
The author of the annotation.
finalinherited
backgroundColor PdfColor?
Background color.
finalinherited
border PdfBorder?
Border for this annotation.
finalinherited
color PdfColor?
Annotation color.
finalinherited
content String?
Text content of the annotation.
finalinherited
date DateTime?
Last modification date.
finalinherited
defaultValue String?
Default value.
final
fieldFlags Set<PdfFieldFlags>?
Field flags.
finalinherited
fieldFlagsValue int
Encoded field flags value.
no setterinherited
fieldName String?
Field name.
finalinherited
fieldType String
Field type name.
finalinherited
flags Set<PdfAnnotFlags>
Flags specifying various characteristics of the annotation.
latefinalinherited
flagValue int
Encoded annotation flags value.
no setterinherited
font PdfFont
Font used to render text.
final
fontSize double
Font size.
final
hashCode int
The hash code for this object.
no setterinherited
highlighting PdfAnnotHighlighting?
Highlighting behavior.
finalinherited
mappingName String?
Mapping name.
finalinherited
maxLength int?
Maximum input length.
final
name String?
Internal name for a link.
finalinherited
rect PdfRect
Annotation rectangle.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subject String?
The subject of the annotation.
finalinherited
subtype String
The annotation subtype.
finalinherited
textAlign PdfTextFieldAlign?
Text alignment.
final
textColor PdfColor
Text color.
final
value String?
Current value.
final

Methods

appearance(PdfDocument pdfDocument, PdfAnnotAppearance type, {String? name, Matrix4? matrix, PdfRect? boundingBox, bool selected = false}) PdfGraphics
Creates and registers a form XObject for the appearance stream.
inherited
build(PdfPage page, PdfObject<PdfDataType> object, PdfDict<PdfDataType> params) → void
Writes text field parameters and default appearance.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited