BksSecretEntry class

Represents a secret value entry in a BKS keystore. This stores arbitrary pre-protected data.

Inheritance

Constructors

BksSecretEntry({required String alias, required int timestamp, required String storeType, required Uint8List secretData, List<BksTrustedCertEntry> certChain = const []})

Properties

alias String
The alias of this entry.
getter/setter pairinherited
certChain List<BksTrustedCertEntry>
Certificate chain associated with this entry.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secretData Uint8List
The raw secret data.
final
storeType String
The type of the store this entry belongs to.
getter/setter pairinherited
timestamp int
The timestamp when this entry was created (milliseconds since epoch).
getter/setter pairinherited

Methods

decrypt(String password) → void
Decrypts this entry using the given password.
override
isDecrypted() bool
Returns true if this entry has been decrypted.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited