IcpBrasilCertificateLoader class

Loads ICP-Brasil certificates from JKS and BKS keystores.

Constructors

IcpBrasilCertificateLoader({String? jksPath, String? bksPath, Uint8List? jksBytes, Uint8List? bksBytes, String jksPassword = '12345678', String bksPassword = 'serprosigner', PkiBytesSource? bytesSource})

Properties

bksBytes Uint8List?
Bytes de BKS já carregados, útil para web/memória.
final
bksPassword String
final
bksPath String?
Caminho local (VM) ou URL/asset (web) do truststore BKS.
final
bytesSource PkiBytesSource
final
hashCode int
The hash code for this object.
no setterinherited
jksBytes Uint8List?
Bytes de JKS já carregados, útil para web/memória.
final
jksPassword String
final
jksPath String?
Caminho local (VM) ou URL/asset (web) do truststore JKS.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

loadFromBks({bool tryDecryptKeys = false}) Future<List<Uint8List>>
loadFromJks({bool verifyIntegrity = false}) Future<List<Uint8List>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited