InMemoryPkiBytesSource class

Fonte de bytes em memória útil para testes e ambiente web sem filesystem.

Inheritance

Constructors

InMemoryPkiBytesSource(Map<String, Uint8List> _items)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read(String location) Future<Uint8List>
Lê bytes de location (caminho local na VM ou URL/asset no navegador).
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited