JksKeyStore class
A class representing a Java KeyStore (JKS).
- Inheritance
-
- Object
- AbstractKeystore
- JksKeyStore
Properties
-
certs
→ Map<
String, TrustedCertEntry> -
Returns all trusted certificate entries.
no setterinherited
-
entries
→ Map<
String, KeystoreEntry> -
Map of aliases to entries.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
privateKeys
→ Map<
String, PrivateKeyEntry> -
Returns all private key entries.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- storeType → String
-
The type of keystore (e.g., "jks", "jceks", "bks").
finalinherited
Methods
-
getAllCertificates(
) → List< Uint8List> -
Gets all certificates from the keystore as DER-encoded bytes.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
save(
String storePassword, {String? keyPassword}) → Uint8List - Saves the keystore to bytes.
-
saveJceks(
String storePassword, {String? keyPassword}) → Uint8List - Saves the keystore to JCEKS format bytes (version 2 with JCEKS magic).
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
load(
Uint8List bytes, {String storePassword = ''}) → JksKeyStore - Loads a JKS keystore from bytes.