OcspEntryStatus class

Helper for OCSP status.

Constructors

OcspEntryStatus({int status = 0, DateTime? revocationTime, int? revocationReason, DateTime? thisUpdate, DateTime? nextUpdate})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
nextUpdate DateTime?
final
revocationReason int?
final
revocationTime DateTime?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status int
final
thisUpdate DateTime?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited