PkiUtils class

Utilities for cryptographic operations and random data.

Constructors

PkiUtils()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

digest(String algorithm, Uint8List data) Future<Uint8List>
Hash via backend de crypto da plataforma.
generateRsaKeyPair({int bitStrength = 2048, int certainty = 64}) AsymmetricKeyPair<PublicKey, PrivateKey>
generateSerialNumberBigInt({int bytes = 16}) BigInt
Generates a cryptographically strong random serial number.
generateSerialNumberBigIntPlatform({int bytes = 16}) BigInt
Gera serial com RNG da plataforma (Web Crypto no navegador).
getPlatformCrypto() PlatformCrypto
getSecureRandom() SecureRandom