TrustedCertEntry class

Represents a trusted certificate entry.

Inheritance
Implementers

Constructors

TrustedCertEntry({required String alias, required int timestamp, required String storeType, required String certType, required Uint8List certData})

Properties

alias String
The alias of this entry.
getter/setter pairinherited
certData Uint8List
The DER-encoded certificate data.
final
certType String
The type of certificate (usually "X.509").
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storeType String
The type of the store this entry belongs to.
getter/setter pairinherited
timestamp int
The timestamp when this entry was created (milliseconds since epoch).
getter/setter pairinherited

Methods

decrypt(String password) → void
Decrypts this entry using the given password.
override
isDecrypted() bool
Returns true if this entry has been decrypted.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited