X509Certificate class

Constructors

X509Certificate.fromDer(Uint8List der)
factory
X509Certificate.fromPem(String pem)
factory

Properties

der Uint8List
final
extensions List<X509Extension>
final
hashCode int
The hash code for this object.
no setterinherited
issuer X509Name
final
notAfter DateTime
final
notBefore DateTime
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serialNumber BigInt
final
serialNumberHex String
no setter
signatureAlgorithmOid String
final
signatureValue Uint8List
final
subject X509Name
final
subjectPublicKeyInfoDer Uint8List
final
tbsDer Uint8List
final
tbsSignatureAlgorithmOid String
final
version int
final

Methods

isValidAt(DateTime instant) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toPem() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited