X509Name class

Constructors

X509Name(List<X509NameAttribute> attributes)
X509Name.fromAsn1(ASN1Sequence seq)
factory

Properties

attributes List<X509NameAttribute>
final
commonName String?
no setter
country String?
no setter
hashCode int
The hash code for this object.
no setterinherited
organization String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited