HttpRevocationDataProvider class

Implemented types

Constructors

HttpRevocationDataProvider()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

fetchCrl(Uri url) Future<Uint8List?>
override
fetchOcsp(Uri url, Uint8List requestDer) Future<Uint8List?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited