PdfAcroChoiceField class
- Inheritance
-
- Object
- PdfAcroField
- PdfAcroChoiceField
Constructors
-
PdfAcroChoiceField(PdfDict<
PdfDataType> dictionary, PdfIndirect? indirectReference, String name, PdfAcroForm acroForm)
Properties
- acroForm → PdfAcroForm
-
finalinherited
-
dictionary
→ PdfDict<
PdfDataType> -
finalinherited
- fieldType → String?
-
Gets the field type (/FT).
no setterinherited
- flags ↔ int
-
Gets the field flags (/Ff).
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
indices
↔ List<
int> -
Gets the indices (/I) of selected items in a multi-select list.
getter/setter pair
- indirectReference → PdfIndirect?
-
finalinherited
- isCombo ↔ bool
-
getter/setter pair
- name → String
-
finalinherited
-
options
→ List<
String> -
Gets the options (/Opt) for the choice field.
no setter
-
rect
↔ List<
double> ? -
Gets the rectangle (/Rect) of the field (widget annotation).
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- topIndex ↔ int
-
Gets the top index (/TI).
getter/setter pair
Methods
-
hasFieldFlag(
int flag) → bool -
Helper to check if a specific flag bit is set.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setFieldFlag(
int flag, bool value) → void -
Helper to set or clear a specific flag bit.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited