PdfAcroField class

Implementers

Constructors

PdfAcroField(PdfDict<PdfDataType> dictionary, PdfIndirect? indirectReference, String name, PdfAcroForm acroForm)
PdfAcroField.create(PdfDict<PdfDataType> dictionary, PdfIndirect? indirectReference, String name, PdfAcroForm acroForm)
Factory to create the correct field type from a dictionary.
factory

Properties

acroForm PdfAcroForm
final
dictionary → PdfDict<PdfDataType>
final
fieldType String?
Gets the field type (/FT).
no setter
flags int
Gets the field flags (/Ff).
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
indirectReference → PdfIndirect?
final
name String
final
rect List<double>?
Gets the rectangle (/Rect) of the field (widget annotation).
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

hasFieldFlag(int flag) bool
Helper to check if a specific flag bit is set.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setFieldFlag(int flag, bool value) → void
Helper to set or clear a specific flag bit.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited