PdfAcroForm class

Constructors

PdfAcroForm(PdfDocument document)

Properties

document PdfDocument
final
fields Map<String, PdfAcroField>
Retrieves the form fields (AcroFields) from the document.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addField(PdfAcroField field, PdfObject<PdfDataType>? page) → void
Adds a new field to the AcroForm and optionally to a specific page (as a Widget).
createButtonField(String name) PdfAcroButtonField
Creates a new Button Field.
createChoiceField(String name) PdfAcroChoiceField
Creates a new Choice Field.
createSignatureField(String name) PdfAcroSignatureField
Creates a new Signature Field.
createTextField(String name) PdfAcroTextField
Creates a new Text Field.
flattenFields() → void
Flattens all form fields, merging their appearances into the page content.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited