PdfAcroTextField class

Inheritance

Constructors

PdfAcroTextField(PdfDict<PdfDataType> dictionary, PdfIndirect? indirectReference, String name, PdfAcroForm acroForm)

Properties

acroForm PdfAcroForm
finalinherited
dictionary → PdfDict<PdfDataType>
finalinherited
fieldType String?
Gets the field type (/FT).
no setterinherited
flags int
Gets the field flags (/Ff).
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
indirectReference → PdfIndirect?
finalinherited
isMultiline bool
Whether the field can contain multiple lines of text.
getter/setter pair
isPassword bool
Whether the field is a password field.
getter/setter pair
maxLength int?
Gets the maximum length of the field's text (/MaxLen).
getter/setter pair
name String
finalinherited
rect List<double>?
Gets the rectangle (/Rect) of the field (widget annotation).
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

hasFieldFlag(int flag) bool
Helper to check if a specific flag bit is set.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setFieldFlag(int flag, bool value) → void
Helper to set or clear a specific flag bit.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

flagMultiline → const int
flagPassword → const int