PdfCmsSigner class
Builds CMS/PKCS#7 structures for PDF signatures.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
buildDetachedCms(
{required Uint8List contentDigest, required Uint8List signerCertDer, List< Uint8List> extraCertsDer = const <Uint8List>[], DateTime? signingTime, String digestAlgorithmOid = '2.16.840.1.101.3.4.2.1', String signatureAlgorithmOid = '1.2.840.113549.1.1.1', required Future<Uint8List> signCallback(Uint8List signedAttrsDer, Uint8List signedAttrsDigest), Future<Uint8List> timestampProvider(Uint8List signature)?}) → Future<Uint8List> - Builds a detached CMS/PKCS#7 signature.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
signDetachedSha256RsaFromPem(
{required Uint8List contentDigest, required String privateKeyPem, required String certificatePem, List< String> chainPem = const <String>[], DateTime? signingTime}) → Uint8List - Helper that builds a detached CMS using PEM materials.
-
signDigestRsaSha256(
Uint8List digest, String privateKeyPem) → Uint8List - Helper to sign a digest using RSA PKCS#1 v1.5 with SHA-256.