PdfCmsValidator class

Constructors

PdfCmsValidator()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
validate(Uint8List cmsBytes, {List<String>? trustedRootsPem, TrustedRootsProvider? trustedRootsProvider, List<TrustedRootsProvider>? trustedRootsProviders, PdfHttpFetcherBase? certificateFetcher, bool requireTrustedChain = false}) Future<PdfCmsValidationResult>

Operators

operator ==(Object other) bool
The equality operator.
inherited