PdfDssData class

Constructors

PdfDssData(PdfDocument document)

Properties

cert List<PdfObjectStream>
final
crl List<PdfObjectStream>
final
document PdfDocument
final
hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
no setter
ocsp List<PdfObjectStream>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addCertBytes(Uint8List bytes) → void
addCrlBytes(Uint8List bytes) → void
addOcspBytes(Uint8List bytes) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited