PdfEcdsaPkcs8Signer class

ECDSA signer backed by PKCS#8 private key (Web Crypto friendly).

Inheritance

Constructors

PdfEcdsaPkcs8Signer({required Uint8List pkcs8PrivateKey, required String namedCurve, required List<Uint8List> certificates, String hashAlgorithm = 'SHA-256', SignatureAdapter? signatureAdapter})

Properties

certificates List<Uint8List>
Public certificate chain of the signer.
no setteroverride
digestAlgorithmOid String
SignerInfo.digestAlgorithm OID.
no setteroverride
hashAlgorithm String
final
hashCode int
The hash code for this object.
no setterinherited
namedCurve String
final
pkcs8PrivateKey Uint8List
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signatureAlgorithmOid String
SignerInfo.signatureAlgorithm OID.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
signDigest(Uint8List digest) Future<Uint8List>
Signs the SHA-256 digest of signedAttrs and returns a raw signature (PKCS#1 v1.5 or ECDSA) to be embedded in the CMS.
override
signSignedAttributes(Uint8List signedAttrsDer, Uint8List signedAttrsDigest) Future<Uint8List>
Optional hook for algorithms that sign signedAttrs bytes directly (ex.: ECDSA/EdDSA em APIs que fazem hashing internamente).
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited