PdfExternalSigner class abstract
Interface for external signing (A3/HSM/services).
Constructors
Properties
-
certificates
→ List<
Uint8List> -
Public certificate chain of the signer.
no setter
- digestAlgorithmOid → String
-
SignerInfo.digestAlgorithm OID.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- signatureAlgorithmOid → String
-
SignerInfo.signatureAlgorithm OID.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
signDigest(
Uint8List digest) → Future< Uint8List> -
Signs the SHA-256 digest of
signedAttrsand returns a raw signature (PKCS#1 v1.5 or ECDSA) to be embedded in the CMS. -
signSignedAttributes(
Uint8List signedAttrsDer, Uint8List signedAttrsDigest) → Future< Uint8List> - Optional hook for algorithms that sign signedAttrs bytes directly (ex.: ECDSA/EdDSA em APIs que fazem hashing internamente).
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited