PdfExternalSigning class

Utilities for external signing (prepare + embed).

Constructors

PdfExternalSigning()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

useFastByteRangeParser bool
Use fast ByteRange parser when possible.
getter/setter pair
useFastContentsParser bool
Use fast /Contents parser when possible.
getter/setter pair
useInternalByteRangeParser bool
Use internal ByteRange parser implementation.
getter/setter pair
useInternalContentsParser bool
Use internal /Contents parser implementation.
getter/setter pair

Static Methods

computeByteRangeDigest(Uint8List pdfBytes, List<int> byteRange) Uint8List
Computes the digest of the content described by byteRange.
computeByteRangeHashBase64(Uint8List pdfBytes, List<int> byteRange) String
Computes a Base64 hash for the content described by byteRange.
embedSignature({required Uint8List preparedPdfBytes, required Uint8List pkcs7Bytes}) Uint8List
Embeds PKCS#7 into the /Contents placeholder.
extractByteRange(Uint8List pdfBytes) List<int>
Extracts the last /ByteRange array from pdfBytes.
findContentsRange(Uint8List pdfBytes, {bool strict = true}) → _ContentsRange
Finds the /Contents hex string range in pdfBytes.
preparePdf({required Uint8List inputBytes, required int pageNumber, required PdfRect bounds, required String fieldName, PdfSignatureConfig? signature, List<List<int>> publicCertificates = const <List<int>>[], void drawAppearance(PdfGraphics graphics, PdfRect bounds)?, int contentsReserveSize = 16384, int byteRangeDigits = 10}) Future<PdfExternalSigningPrepared>
Prepares a PDF with a signature placeholder and returns ByteRange + hash.