PdfHttpResponse class

Constructors

PdfHttpResponse({required int statusCode, required Uint8List body, Map<String, String> headers = const <String, String>{}, Duration? requestTime, Duration? responseTime, Duration? totalTime})
const

Properties

body Uint8List
final
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>
final
requestTime Duration?
final
responseTime Duration?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int
final
totalTime Duration?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited