PdfInMemoryTrustedRootsProvider class

In-memory roots provider useful for VM and Web.

Implemented types

Constructors

PdfInMemoryTrustedRootsProvider(List<Uint8List> _roots)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getTrustedRootsDer() Future<List<Uint8List>>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited