PdfItiComplianceMetadata class

Constructors

PdfItiComplianceMetadata({String name = 'Validar', DateTime? validationDate, String verifierVersion = 'Não informado', String validatorVersion = 'Não informado', String verificationSource = 'Offline'})

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
validationDate DateTime
final
validatorVersion String
final
verificationSource String
final
verifierVersion String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited