PdfItiLpaInfo class

Constructors

PdfItiLpaInfo({bool? lpaValid, DateTime? nextIssue, bool? lpaExpired, String? lpaName, bool? lpaOnline, String? lpaVersion})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
lpaExpired bool?
final
lpaName String?
final
lpaOnline bool?
final
lpaValid bool?
final
lpaVersion String?
final
nextIssue DateTime?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited