PdfItiPolicyInfo class

Constructors

PdfItiPolicyInfo({bool? paValid, DateTime? paValidFrom, DateTime? paValidTo, bool? paExpired, bool? paValidInLpa, bool? paOnline, String? paOidLabel})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
paExpired bool?
final
paOidLabel String?
final
paOnline bool?
final
paValid bool?
final
paValidFrom DateTime?
final
paValidInLpa bool?
final
paValidTo DateTime?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited