PdfLpa class

Constructors

PdfLpa({required List<PdfLpaPolicyInfo> policies, int? version, DateTime? nextUpdate})

Properties

hashCode int
The hash code for this object.
no setterinherited
nextUpdate DateTime?
final
policies List<PdfLpaPolicyInfo>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version int?
final

Methods

findPolicy(String oid) PdfLpaPolicyInfo?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

parse(Uint8List der) PdfLpa