PdfLpaPolicyInfo class

Constructors

PdfLpaPolicyInfo({required String policyOid, required String policyUri, DateTime? notBefore, DateTime? notAfter, DateTime? revocationDate, String? hashAlgorithmOid, Uint8List? hashValue})

Properties

hashAlgorithmOid String?
final
hashCode int
The hash code for this object.
no setterinherited
hashValue Uint8List?
final
notAfter DateTime?
final
notBefore DateTime?
final
policyOid String
final
policyUri String
final
revocationDate DateTime?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited