PdfLtvService class

Constructors

PdfLtvService()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

applyLtv({required Uint8List pdfBytes, List<Uint8List> crl = const <Uint8List>[], List<Uint8List> ocsp = const <Uint8List>[], List<Uint8List> certs = const <Uint8List>[]}) Future<({bool applied, Uint8List bytes})>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited