PdfPolicyResolution class

Constructors

PdfPolicyResolution({required int signatureIndex, String? policyOid, String? displayName, bool? lpaMatch, bool? validAtSigningTime, bool? validNow, bool? digestMatch})
const
PdfPolicyResolution.fromJson(Map<String, dynamic> json)
factory

Properties

digestMatch bool?
final
displayName String?
final
hashCode int
The hash code for this object.
no setterinherited
lpaMatch bool?
final
policyOid String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signatureIndex int
final
validAtSigningTime bool?
final
validNow bool?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited