PdfPreflightSignatureFastInfo class

Constructors

PdfPreflightSignatureFastInfo({required int signatureIndex, required String fieldName, String? serialDecimal, String? serialHex, String? issuerDn, String? policyOid, DateTime? signingTime, String? authorityKeyIdentifierHex, String? notes})
const
PdfPreflightSignatureFastInfo.fromJson(Map<String, dynamic> json)
factory

Properties

authorityKeyIdentifierHex String?
final
fieldName String
final
hashCode int
The hash code for this object.
no setterinherited
issuerDn String?
final
notes String?
final
policyOid String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serialDecimal String?
final
serialHex String?
final
signatureIndex int
final
signingTime DateTime?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited