signedLength property
Offset up to which the /ByteRange protects the document (start2 + len2
of the range). Bytes beyond this offset are not covered by this signature.
Implementation
final int signedLength;
Offset up to which the /ByteRange protects the document (start2 + len2
of the range). Bytes beyond this offset are not covered by this signature.
final int signedLength;