PdfSignatureExtractionInfo class

Constructors

PdfSignatureExtractionInfo({required int signatureIndex, PdfSignatureFieldInfo? signatureField, bool? contentsPresent, DateTime? signingTime, String? signaturePolicyOid, List<String>? signedAttrsOids, List<PdfSignatureCertificateInfo>? certificates, PdfSignatureCertificateInfo? signerCertificate, String? message})
const

Properties

certificates List<PdfSignatureCertificateInfo>?
final
contentsPresent bool?
final
hashCode int
The hash code for this object.
no setterinherited
message String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signatureField PdfSignatureFieldInfo?
final
signatureIndex int
final
signaturePolicyOid String?
final
signedAttrsOids List<String>?
final
signerCertificate PdfSignatureCertificateInfo?
final
signingTime DateTime?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited