PdfSignatureExtractor class

Extrator de informações de assinatura sem validação criptográfica.

Constructors

PdfSignatureExtractor({PdfSignatureValidator? validator})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

extractSignatures(Uint8List pdfBytes, {bool includeCertificates = true, bool includeSignatureFields = true, PdfSignaturePreparedContext? preparedContext}) Future<PdfSignatureExtractionReport>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited