PdfSignatureFieldEditContext class

Constructors

PdfSignatureFieldEditContext({required List<PdfSignatureFieldObjectInfo> fields, PdfIndirectRef? acroFormRef, PdfDict<PdfDataType>? acroFormDict, PdfIndirectRef? fieldsRef, PdfArray<PdfDataType>? fieldsArray})
const

Properties

acroFormDict → PdfDict<PdfDataType>?
final
acroFormRef PdfIndirectRef?
final
fields List<PdfSignatureFieldObjectInfo>
final
fieldsArray → PdfArray<PdfDataType>?
final
fieldsRef PdfIndirectRef?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited