PdfSignatureFieldInfo class

Constructors

PdfSignatureFieldInfo({required String? fieldName, String? reason, String? location, String? name, String? signingTimeRaw, String? filter, String? subFilter, List<int>? byteRange, PdfIndirectRef? pageRef, int? pageIndex, List<double>? rect, bool? signatureDictionaryPresent})
const

Properties

byteRange List<int>?
final
fieldName String?
final
filter String?
final
hashCode int
The hash code for this object.
no setterinherited
location String?
final
name String?
final
pageIndex int?
final
pageRef PdfIndirectRef?
final
reason String?
final
rect List<double>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signatureDictionaryPresent bool?
final
signingTimeRaw String?
final
subFilter String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited