PdfSignatureFieldObjectInfo class

Constructors

PdfSignatureFieldObjectInfo({required PdfSignatureFieldInfo info, PdfIndirectRef? fieldRef, required PdfDict<PdfDataType> fieldDict, int? fieldIndex, bool isDirect = false, PdfIndirectRef? signatureRef, PdfDict<PdfDataType>? signatureDict})
const

Properties

fieldDict → PdfDict<PdfDataType>
final
fieldIndex int?
final
fieldRef PdfIndirectRef?
final
hashCode int
The hash code for this object.
no setterinherited
info PdfSignatureFieldInfo
final
isDirect bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signatureDict → PdfDict<PdfDataType>?
final
signatureRef PdfIndirectRef?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited