PdfSignatureIcpBrasilIds class
Constructors
Properties
- cei → String?
-
final
- cnpj → String?
-
final
- cpf → String?
-
final
- dateOfBirth → DateTime?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- nis → String?
-
final
-
raw
→ Map<
String, String> ? -
final
- responsavelCpf → String?
-
final
- responsavelNome → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tituloEleitor → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromOtherNames(
List< PdfSignatureOtherName> otherNames) → PdfSignatureIcpBrasilIds?