PdfSignatureInspector class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
inspect(Uint8List pdfBytes, {List<String>? trustedRootsPem, TrustedRootsProvider? trustedRootsProvider, List<TrustedRootsProvider>? trustedRootsProviders, bool strictRevocation = false, bool fetchCrls = false, bool fetchOcsp = false, PdfRevocationDataProvider? revocationDataProvider, PdfHttpFetcherBase? certificateFetcher, bool includeCertificates = true, bool includeSignatureFields = true})
→ Future<PdfSignatureInspectionReport>
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited