PdfSignatureRequest class

Constructors

PdfSignatureRequest({required int pageNumber, required PdfSignatureSigner signer, required PdfSignatureBounds bounds, String fieldName = 'Signature1', String? reason, String? location, String? contactInfo, String? name, DateTime? signingTime, PdfSignatureAppearance? appearance, Widget? appearanceWidget, void drawAppearance(PdfGraphics graphics, PdfRect bounds)?, int? docMdpPermissionP, PdfTimestampProvider? timestampProvider, int contentsReserveSize = 16384, int byteRangeDigits = 10})
Creates a request for adding a signature to a loaded document.

Properties

appearance → PdfSignatureAppearance?
final
appearanceWidget Widget?
final
bounds PdfSignatureBounds
final
byteRangeDigits int
final
contactInfo String?
final
contentsReserveSize int
final
docMdpPermissionP int?
final
drawAppearance → void Function(PdfGraphics graphics, PdfRect bounds)?
Custom appearance drawer for the signature widget.
final
fieldName String
final
hashCode int
The hash code for this object.
no setterinherited
location String?
final
name String?
final
pageNumber int
final
reason String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signer PdfSignatureSigner
final
signingTime DateTime?
final
timestampProvider PdfTimestampProvider?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited