PdfSignatureRevocationInfo class

Constructors

PdfSignatureRevocationInfo({bool crlChecked = false, bool crlRevoked = false, bool ocspChecked = false, bool ocspRevoked = false, bool revocationUnknown = true})
const

Properties

crlChecked bool
final
crlRevoked bool
final
hashCode int
The hash code for this object.
no setterinherited
ocspChecked bool
final
ocspRevoked bool
final
revocationUnknown bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited