PdfSignatureSignedAttrsReport class

Constructors

PdfSignatureSignedAttrsReport({required List<String> requiredOids, required List<String> optionalOids, required List<String> missingRequiredOids, required List<String> presentOids})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
missingRequiredOids List<String>
final
optionalOids List<String>
final
presentOids List<String>
final
requiredOids List<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited