PdfSignatureSignerInfo class
Constructors
Properties
- certNotAfter → DateTime?
-
final
- certNotBefore → DateTime?
-
final
- commonName → String?
-
final
- cpf → String?
-
final
- dateOfBirth → DateTime?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- issuer → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serialNumberDecimal → String?
-
final
- serialNumberHex → String?
-
final
- subject → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited