PdfSignatureSummary class

Constructors

PdfSignatureSummary({required int signatureIndex, required String fieldName, required PdfSignatureSignerInfo? signer, required DateTime? signingTime, required bool policyPresent, required bool? policyDigestOk, required bool cmsSignatureValid, required bool byteRangeDigestOk, required bool documentIntact, required bool? chainTrusted, required PdfSignatureDocMdpInfo? docMdp})
const

Properties

byteRangeDigestOk bool
final
chainTrusted bool?
final
cmsSignatureValid bool
final
docMdp PdfSignatureDocMdpInfo?
final
documentIntact bool
final
fieldName String
final
hashCode int
The hash code for this object.
no setterinherited
policyDigestOk bool?
final
policyPresent bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signatureIndex int
final
signer PdfSignatureSignerInfo?
final
signingTime DateTime?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited