PdfSignatureValidationResult class

Constructors

PdfSignatureValidationResult({required int signatureIndex, required bool cmsValid, required bool digestValid, required bool intact, String? message})
const

Properties

cmsValid bool
final
digestValid bool
final
hashCode int
The hash code for this object.
no setterinherited
intact bool
final
message String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signatureIndex int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited