PdfSignatureValidator class

Validador básico de assinaturas (PAdES).

Constructors

PdfSignatureValidator({bool enableInMemoryParseCache = false})

Properties

enableInMemoryParseCache bool
Habilita cache de parse por identidade do Uint8List em memória.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
prepareContext(Uint8List pdfBytes, {bool includeSignatureFields = true, bool includeSignatureContents = false, PdfSignaturePreparedContext? baseContext}) PdfSignaturePreparedContext
toString() String
A string representation of this object.
inherited
validateAllSignatures(Uint8List pdfBytes, {List<String>? trustedRootsPem, TrustedRootsProvider? trustedRootsProvider, List<TrustedRootsProvider>? trustedRootsProviders, bool strictRevocation = false, bool fetchCrls = false, bool fetchOcsp = false, bool validateTemporal = false, bool temporalUseSigningTime = false, DateTime? validationTime, bool temporalExpiredNeedsLtv = true, PdfRevocationDataProvider? revocationDataProvider, PdfHttpFetcherBase? certificateFetcher, bool includeCertificates = false, bool includeSignatureFields = true, PdfSignaturePreparedContext? preparedContext}) Future<PdfSignatureValidationReport>
Valida todas as assinaturas do PDF.
validateAllSignaturesLegacy(Uint8List pdfBytes, {PdfSignaturePreparedContext? preparedContext}) Future<List<PdfSignatureValidationResult>>
API legada: retorna apenas resultados básicos.

Operators

operator ==(Object other) bool
The equality operator.
inherited