PdfSmartSignatureValidator class

Wrapper around PdfSignatureValidator with smart trusted-root selection.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
validateAllSignatures(Uint8List pdfBytes, {required PdfSmartTrustedRootsSelector rootsSelector, PdfSignaturePreparedContext? preparedContext, List<String>? trustedRootsPem, List<TrustedRootsProvider>? additionalTrustedRootsProviders, bool strictRevocation = false, bool fetchCrls = false, bool fetchOcsp = false, bool validateTemporal = false, bool temporalUseSigningTime = false, DateTime? validationTime, bool temporalExpiredNeedsLtv = true, PdfRevocationDataProvider? revocationDataProvider, bool includeCertificates = false, bool includeSignatureFields = true}) Future<PdfSmartSignatureValidationResult>

Operators

operator ==(Object other) bool
The equality operator.
inherited