PdfSmartTrustedRootsSelector class

Smart roots selector based on signer issuer names extracted from PDF CMS.

Constructors

PdfSmartTrustedRootsSelector(PdfTrustedRootsIndex index, {bool fallbackToAllSources = true, bool requireFullIssuerCoverage = true})

Properties

fallbackToAllSources bool
final
hashCode int
The hash code for this object.
no setterinherited
index PdfTrustedRootsIndex
final
requireFullIssuerCoverage bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearCache() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
selectForPdf(Uint8List pdfBytes) Future<PdfTrustedRootsSelection>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited