PdfTimestampClient class

RFC 3161 TSA client.

Constructors

PdfTimestampClient({required Uri endpoint, PdfTimestampHashAlgorithm hashAlgorithm = PdfTimestampHashAlgorithm.sha256, PdfTimestampValidationOptions? validationOptions, PdfHttpFetcherBase? httpClient})
Creates a TSA client.
PdfTimestampClient.freetsa({PdfTimestampHashAlgorithm hashAlgorithm = PdfTimestampHashAlgorithm.sha256, PdfTimestampValidationOptions? validationOptions})
Creates a client configured for FreeTSA.
factory

Properties

endpoint Uri
TSA endpoint.
final
hashAlgorithm PdfTimestampHashAlgorithm
Hash algorithm for timestamp requests.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
validationOptions PdfTimestampValidationOptions?
Optional validation options.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
timestampSignature(Uint8List signature, {PdfTimestampValidationOptions? validationOptions}) Future<Uint8List>
Requests a timestamp token for signature.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited