PdfTimestampValidationOptions class

Validation options for TSA responses.

Constructors

PdfTimestampValidationOptions({List<String>? trustedRootsPem, TrustedRootsProvider? trustedRootsProvider, List<TrustedRootsProvider>? trustedRootsProviders, PdfHttpFetcherBase? certificateFetcher, bool requireTrustedChain = true, bool throwOnFailure = true})
Creates TSA validation options.
const

Properties

certificateFetcher PdfHttpFetcherBase?
Optional certificate fetcher (AIA).
final
hashCode int
The hash code for this object.
no setterinherited
requireTrustedChain bool
Whether a trusted chain is required.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
throwOnFailure bool
Whether to throw when validation fails.
final
trustedRootsPem List<String>?
PEM-encoded trusted roots.
final
trustedRootsProvider TrustedRootsProvider?
Trusted roots provider.
final
trustedRootsProviders List<TrustedRootsProvider>?
Multiple trusted roots providers.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited