PdfTrustResolutionBySignature class

Constructors

PdfTrustResolutionBySignature({required int signatureIndex, required String fieldName, required Map<String, bool> trustedByProfile, required String? winningProfile, required List<String> reasons})
const
PdfTrustResolutionBySignature.fromJson(Map<String, dynamic> json)
factory

Properties

fieldName String
final
hashCode int
The hash code for this object.
no setterinherited
reasons List<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signatureIndex int
final
trustedByProfile Map<String, bool>
final
winningProfile String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited