PdfTrustedRootsIndex class

Index of trusted roots for fast source selection.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceIds List<String>
no setter

Methods

allRoots() List<Uint8List>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rootsForSource(String sourceId) List<Uint8List>
subjectsForSource(String sourceId) Set<String>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited