PdfTrustedRootsSelection class

Selection result containing the chosen roots and diagnostics.

Constructors

PdfTrustedRootsSelection({required List<String> selectedSourceIds, required List<Uint8List> roots, required bool fallbackToAllSources, required String reason})
const

Properties

fallbackToAllSources bool
final
hashCode int
The hash code for this object.
no setterinherited
provider TrustedRootsProvider
no setter
reason String
final
roots List<Uint8List>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedSourceIds List<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited