PdfUiSignatureSummary class

Constructors

PdfUiSignatureSummary({required int signatureIndex, required String nome, required String cpfMasked, required String cadeia, required bool integridade, required List<String> alertas})
const

Properties

alertas List<String>
final
cadeia String
final
cpfMasked String
final
hashCode int
The hash code for this object.
no setterinherited
integridade bool
final
nome String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signatureIndex int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited