PdfValidationApi class

Constructors

PdfValidationApi({PdfSignatureValidator? validator, PdfSignatureExtractor? extractor})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

evaluateDocMdp(PdfSignatureValidationReport report) PdfDocMdpEvaluation
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
preflightSignaturesFast(Uint8List pdfBytes, {PdfSignaturePreparedContext? preparedContext, PdfValidationCacheHooks? cacheHooks, Duration cacheTtl = const Duration(minutes: 2), bool incremental = true}) Future<PdfPreflightSignaturesFastReport>
toComplianceReport({required Uint8List pdfBytes, required PdfValidationWithProfilesResult result, required PdfComplianceReportFormat format, String fileName = 'Arquivo PDF', PdfLpa? lpa, String? lpaName, bool? lpaOnline, bool? paOnline, PdfItiComplianceMetadata? metadata}) PdfComplianceReportOutput
toString() String
A string representation of this object.
inherited
toUiSummary(PdfValidationWithProfilesResult result, {String locale = 'pt_BR'}) PdfUiSummary
validateBatch(List<PdfBatchValidationInput> batch, {required List<PdfTrustProfile> trustProfiles, bool strictRevocation = false, bool fetchCrls = false, bool fetchOcsp = false, bool validateTemporal = false, bool temporalUseSigningTime = false, DateTime? validationTime, bool temporalExpiredNeedsLtv = true, PdfRevocationDataProvider? revocationDataProvider, bool includeCertificates = true, bool includeSignatureFields = true, PdfLpa? lpa, Map<String, String>? policyDisplayMap, PdfValidationCacheHooks? cacheHooks, Duration cacheTtl = const Duration(minutes: 2)}) Future<PdfBatchValidationResult>
validateWithTrustProfiles(Uint8List pdfBytes, {PdfSignaturePreparedContext? preparedContext, required List<PdfTrustProfile> trustProfiles, bool strictRevocation = false, bool fetchCrls = false, bool fetchOcsp = false, bool validateTemporal = false, bool temporalUseSigningTime = false, DateTime? validationTime, bool temporalExpiredNeedsLtv = true, PdfRevocationDataProvider? revocationDataProvider, bool includeCertificates = true, bool includeSignatureFields = true, PdfLpa? lpa, Map<String, String>? policyDisplayMap, PdfValidationCacheHooks? cacheHooks, Duration cacheTtl = const Duration(minutes: 2)}) Future<PdfValidationWithProfilesResult>

Operators

operator ==(Object other) bool
The equality operator.
inherited