PdfValidationCacheHooks class

Constructors

PdfValidationCacheHooks({Future<Object?> get(String key)?, Future<void> put(String key, Object value, Duration ttl)?, Future<String?> getJson(String key)?, Future<void> putJson(String key, String value, Duration ttl)?})
const

Properties

get Future<Object?> Function(String key)?
final
getJson Future<String?> Function(String key)?
final
hashCode int
The hash code for this object.
no setterinherited
put Future<void> Function(String key, Object value, Duration ttl)?
final
putJson Future<void> Function(String key, String value, Duration ttl)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited