PdfValidationWithProfilesResult class

Constructors

PdfValidationWithProfilesResult({required PdfSignatureValidationReport report, required List<PdfTrustResolutionBySignature> trustResolutionBySignature, required List<PdfRevocationEvidence> revocationEvidence, required List<PdfPolicyResolution> policyResolver, required PdfDocMdpEvaluation docMdpEvaluation})
const
PdfValidationWithProfilesResult.fromJson(Map<String, dynamic> json)
factory

Properties

docMdpEvaluation PdfDocMdpEvaluation
final
hashCode int
The hash code for this object.
no setterinherited
policyResolver List<PdfPolicyResolution>
final
report PdfSignatureValidationReport
final
revocationEvidence List<PdfRevocationEvidence>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
trustResolutionBySignature List<PdfTrustResolutionBySignature>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited