PdfVisualFont class

Lightweight font descriptor for drawing visual elements.

Constructors

PdfVisualFont.standard(PdfVisualFontFamily? family, double size, {PdfVisualFontStyle style = PdfVisualFontStyle.normal})
PdfVisualFont.ttf(Uint8List bytes, double size, {PdfVisualFontStyle style = PdfVisualFontStyle.normal})

Properties

family PdfVisualFontFamily?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size double
final
style PdfVisualFontStyle
final

Methods

ascent(PdfDocument document) double
descent(PdfDocument document) double
height(PdfDocument document) double
lineHeight(PdfDocument document) double
measureString(PdfDocument document, String text) PdfVisualStringMetrics
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(PdfDocument document) PdfFont
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited