SpanningTableCell class

Annotations
  • @immutable

Constructors

SpanningTableCell({required Widget child, int columnSpan = 1, int rowSpan = 1, EdgeInsetsGeometry padding = EdgeInsets.zero, AlignmentGeometry? alignment, BoxDecoration? decoration, TableCellVerticalAlignment? verticalAlignment})
const

Properties

alignment AlignmentGeometry?
final
child Widget
final
columnSpan int
final
decoration BoxDecoration?
final
hashCode int
The hash code for this object.
no setterinherited
padding EdgeInsetsGeometry
final
rowSpan int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
verticalAlignment TableCellVerticalAlignment?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited