SpanningTableOverflowMode enum
Controls how SpanningTable handles a row group that is taller than the available page height.
Values
- strict → const SpanningTableOverflowMode
-
Throw a SpanningTableException when a row group cannot fit on a page.
- clip → const SpanningTableOverflowMode
-
Clip the row group to the available page height and continue rendering.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
SpanningTableOverflowMode> - A constant List of the values in this enum, in order of their declaration.