BaseAsymmetricBlockCipher class abstract
- Inheritance
-
- Object
- AsymmetricBlockCipher
- BaseAsymmetricBlockCipher
Constructors
Properties
- algorithmName → String
-
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- inputBlockSize → int
-
The input block size of the cipher.
no setterinherited
- outputBlockSize → int
-
The output block size of the cipher.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
init(
bool forEncryption, CipherParameters params) → void -
Initialise the cipher for processing.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
process(
Uint8List data) → Uint8List -
Helper to process a whole block at once
inherited
-
processBlock(
Uint8List inp, int inpOff, int len, Uint8List out, int outOff) → int -
Process a block of data.
inherited
-
reset(
) → void -
Reset the cipher.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited