Digest class abstract
The interface for digests (hash functions).
- Implemented types
- Implementers
Constructors
- Digest()
Properties
- algorithmName → String
-
no setterinherited
- byteLength → int
-
no setter
- digestSize → int
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
doFinal(
Uint8List out, int outOff) → int -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
process(
Uint8List data) → Uint8List -
reset(
) → void -
toString(
) → String -
A string representation of this object.
inherited
-
update(
Uint8List inp, int inpOff, int len) → void -
updateByte(
int inp) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited