PdfJpegInfo class
JPEG metadata extraction.
Constructors
- PdfJpegInfo(Uint8List image)
-
Loads a JPEG image's metadata from raw bytes.
factory
Properties
- exifVersion → String?
-
EXIF version.
no setter
- flashpixVersion → String?
-
Flashpix format version.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → int
-
Height of the image.
final
- isRGB → bool
-
Whether the image is color (RGB) or greyscale.
no setter
- orientation → PdfImageOrientation
-
Rotation angle of this image.
no setter
- pixelXDimension → int?
-
Exif horizontal pixel dimension.
no setter
- pixelYDimension → int?
-
Exif vertical pixel dimension.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
Exif tags discovered.
final
- width → int?
-
Width of the image.
final
- xResolution → double?
-
Exif horizontal resolution.
no setter
- yResolution → double?
-
Exif vertical resolution.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited