menu
pdf_plus package
documentation
pdf.dart
PdfRandomAccessReader class
PdfRandomAccessReader class
dark_mode
light_mode
PdfRandomAccessReader
class
abstract
Leitor randômico síncrono para PDF.
Implementers
PdfCachedRandomAccessReader
PdfMemoryRandomAccessReader
Constructors
PdfRandomAccessReader
()
Properties
hashCode
→
int
The hash code for this object.
no setter
inherited
length
→
int
no setter
runtimeType
→
Type
A representation of the runtime type of the object.
no setter
inherited
Methods
close
(
)
→ void
noSuchMethod
(
Invocation
invocation
)
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readAll
(
)
→
Uint8List
readRange
(
int
offset
,
int
length
)
→
Uint8List
toString
(
)
→
String
A string representation of this object.
inherited
Operators
operator ==
(
Object
other
)
→
bool
The equality operator.
inherited
pdf_plus package
documentation
pdf
PdfRandomAccessReader class
pdf library