PdfRect class
Immutable rectangle in PDF user space.
- Annotations
-
- @immutable
Constructors
- PdfRect(double left, double bottom, double width, double height)
-
Creates a rectangle from left, bottom, width and height.
const
- PdfRect.fromLBRT(double left, double bottom, double right, double top)
-
Creates a rectangle from left, bottom, right and top.
factory
- PdfRect.fromLTRB(double left, double bottom, double right, double top)
-
Creates a rectangle from left, bottom, right, top (deprecated).
factory
- PdfRect.fromLTWH(double left, double top, double width, double height)
-
Creates a rectangle from left, top, width and height.
factory
- PdfRect.fromPoints(PdfPoint offset, PdfPoint size)
-
Creates a rectangle from origin and size points.
factory
Properties
- bottom → double
-
Left coordinate in PDF user space.
final
- bottomLeft → PdfPoint
-
Bottom-left point (deprecated alias).
no setter
- bottomRight → PdfPoint
-
Bottom-right point (deprecated alias).
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
Left coordinate in PDF user space.
final
- horizondalCenter → double
-
Horizontal center (deprecated alias).
no setter
- horizontalCenter → double
-
Horizontal center.
no setter
- left → double
-
Left coordinate in PDF user space.
final
- leftBottom → PdfPoint
-
Left-bottom point.
no setter
- leftTop → PdfPoint
-
Left-top point.
no setter
- offset → PdfPoint
-
Returns the rectangle origin as a point.
no setter
- right → double
-
Right coordinate.
no setter
- rightBottom → PdfPoint
-
Right-bottom point.
no setter
- rightTop → PdfPoint
-
Right-top point.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → PdfPoint
-
Returns the rectangle size as a point.
no setter
- top → double
-
Top coordinate.
no setter
- topLeft → PdfPoint
-
Top-left point (deprecated alias).
no setter
- topRight → PdfPoint
-
Top-right point (deprecated alias).
no setter
- verticalCenter → double
-
Vertical center.
no setter
- width → double
-
Left coordinate in PDF user space.
final
- x → double
-
Left coordinate (deprecated alias).
no setter
- y → double
-
Bottom coordinate (deprecated alias).
no setter
Methods
-
copyWith(
{double? x, double? left, double? y, double? bottom, double? width, double? height}) → PdfRect - Returns a copy with the provided values replaced.
-
deflate(
double delta) → PdfRect - Returns a new rectangle with edges moved inwards by the given delta.
-
inflate(
double delta) → PdfRect - Returns a new rectangle with edges moved outwards by the given delta.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator *(
double factor) → PdfRect -
Scales the rectangle by
factor. -
operator ==(
Object other) → bool -
The equality operator.
inherited