PdfSignatureFieldEditor class
Constructors
- PdfSignatureFieldEditor({required PdfDocument document, required PdfSignatureFieldEditContext context})
- Creates a signature field editor for a document.
Properties
- context → PdfSignatureFieldEditContext
-
The edit context backing the field list.
final
- document → PdfDocument
-
The owning document.
final
-
fields
→ List<
PdfSignatureFieldObjectInfo> -
All signature fields.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addEmptySignatureField(
{required PdfPage page, required PdfRect bounds, required String fieldName}) → PdfAnnotSign - Adds an empty signature widget to a page.
-
clearSignatureValue(
PdfSignatureFieldObjectInfo field) → bool - Clears the signature value (/V) for a field.
-
findByName(
String name) → PdfSignatureFieldObjectInfo? - Finds a signature field by name.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeField(
PdfSignatureFieldObjectInfo field) → bool - Removes a field from the AcroForm fields array.
-
removeFieldByName(
String name) → bool - Removes a field by name.
-
renameField(
PdfSignatureFieldObjectInfo field, String newName) → bool - Renames a field.
-
renameFieldByName(
String currentName, String newName) → bool - Renames a field by name.
-
toString(
) → String -
A string representation of this object.
inherited
-
updateFieldDict(
PdfSignatureFieldObjectInfo field, PdfDict< PdfDataType> updated) → bool - Replaces the field dictionary with a prebuilt one.
-
updateFieldMetadata(
PdfSignatureFieldObjectInfo field, {String? reason, String? location, String? name, String? signingTimeRaw}) → bool - Updates metadata stored in the field dictionary.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited