PdfSignatureTools class
Convenience helpers for external signing workflows.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
embedExternalSignature(
{required Uint8List preparedPdfBytes, required Uint8List pkcs7Bytes}) → Uint8List - Embeds a PKCS#7 signature into prepared PDF bytes.
-
prepareExternalSignature(
{required Uint8List inputBytes, required int pageNumber, required PdfRect bounds, required String fieldName, PdfSignatureConfig? signature, List< List< publicCertificates = const <List<int>>[], void drawAppearance(PdfGraphics graphics, PdfRect bounds)?}) → Future<int> >PdfExternalSigningPrepared> - Prepares a PDF for external signing using PDF-space bounds.
-
prepareExternalSignatureTopLeft(
{required Uint8List inputBytes, required int pageNumber, required double left, required double top, required double width, required double height, required String fieldName, PdfSignatureConfig? signature, List< List< publicCertificates = const <List<int>>[], void drawAppearance(PdfGraphics graphics, PdfRect bounds)?}) → Future<int> >PdfExternalSigningPrepared> - Prepares a PDF for external signing using top-left coordinates.