PdfaAttachedFiles class
Constructors
-
PdfaAttachedFiles(PdfDocument pdfDocument, Map<
String, String> files)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotEmpty → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
catalogAF(
) → PdfArray< PdfDataType> -
catalogNames(
) → PdfDict< PdfDataType> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited