AbstractKeystore class abstract
Abstract base class for keystores.
- Implementers
Constructors
-
AbstractKeystore(String storeType, Map<
String, KeystoreEntry> entries)
Properties
-
certs
→ Map<
String, TrustedCertEntry> -
Returns all trusted certificate entries.
no setter
-
entries
→ Map<
String, KeystoreEntry> -
Map of aliases to entries.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
privateKeys
→ Map<
String, PrivateKeyEntry> -
Returns all private key entries.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- storeType → String
-
The type of keystore (e.g., "jks", "jceks", "bks").
final
Methods
-
getAllCertificates(
) → List< Uint8List> - Gets all certificates from the keystore as DER-encoded bytes.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited