KeystoreEntry class abstract
Represents an entry in a keystore.
Constructors
- KeystoreEntry({required String alias, required int timestamp, required String storeType})
Properties
- alias ↔ String
-
The alias of this entry.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- storeType ↔ String
-
The type of the store this entry belongs to.
getter/setter pair
- timestamp ↔ int
-
The timestamp when this entry was created (milliseconds since epoch).
getter/setter pair
Methods
-
decrypt(
String password) → void - Decrypts this entry using the given password.
-
isDecrypted(
) → bool - Returns true if this entry has been decrypted.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited