Pkcs12Bundle class
Constructors
-
Pkcs12Bundle({required String privateKeyPem, required String certificatePem, List<
String> chainPem = const <String>[]})
Properties
- certificatePem → String
-
final
-
chainPem
→ List<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- privateKeyPem → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited