PkiPemUtils class
Utilities to export PKI material (DER/keys) into PEM.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
certificateChainDerToPem(
List< Uint8List> chainDer) → List<String> - Encodes a list of certificate DER blobs to PEM list.
-
certificateChainDerToPemBundle(
List< Uint8List> chainDer) → String - Encodes a list of certificate DER blobs into a single PEM bundle.
-
certificateDerToPem(
Uint8List der) → String - Encodes a certificate DER to PEM.
-
rsaPrivateKeyToPem(
RSAPrivateKey privateKey, {BigInt? publicExponent}) → String - Encodes an RSA private key (PKCS#1) to PEM.