PdfDocumentInfo class
Constructors
-
PdfDocumentInfo({required String version, PdfIndirectRef? infoRef, Map<
String, String> ? infoDict, required int pageCount, required List<PdfPageMediaBoxInfo> mediaBoxes, required List<PdfImageInfo> images}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
images
→ List<
PdfImageInfo> -
final
-
infoDict
→ Map<
String, String> ? -
final
- infoRef → PdfIndirectRef?
-
final
-
mediaBoxes
→ List<
PdfPageMediaBoxInfo> -
final
- pageCount → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- version → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited