PdfExternalSigningPrepared class
Result of preparing a PDF for external signing.
Constructors
-
PdfExternalSigningPrepared({required Uint8List preparedPdfBytes, required List<
int> byteRange, required String hashBase64}) -
const
Properties
-
byteRange
→ List<
int> -
ByteRange array used for hashing.
final
- hashBase64 → String
-
Base64-encoded hash of the ByteRange content.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- preparedPdfBytes → Uint8List
-
PDF bytes with signature placeholder.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited