PdfHttpFetcherBase class abstract
Provider de download de certificados (AIA/caIssuers) e POST simples.
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
fetchBytes(
Uri url) → Future< Uint8List?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
postBytes(
Uri url, {Map< String, String> ? headers, Uint8List? body, Duration? timeout}) → Future<PdfHttpResponse> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited