PdfImageInfo class
Constructors
- PdfImageInfo({required int pageIndex, required PdfIndirectRef pageRef, required PdfIndirectRef imageRef, required int? width, required int? height, required int? bitsPerComponent, required String? colorSpace, required String? filter})
-
const
Properties
- bitsPerComponent → int?
-
final
- colorSpace → String?
-
final
- filter → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → int?
-
final
- imageRef → PdfIndirectRef
-
final
- pageIndex → int
-
final
- pageRef → PdfIndirectRef
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- width → int?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited