PdfItiCertificateReport class
Constructors
Properties
- fetchSource → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isSignature → String
-
final
- issuer → String
-
final
- notAfter → String
-
final
- notBefore → String
-
final
- revoked → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subject → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited