PdfLoadedDocument class
Represents a PDF loaded from bytes and ready for incremental signing.
Constructors
- PdfLoadedDocument.fromBytes(Uint8List bytes)
-
Parses a PDF from raw bytes.
factory
Properties
Methods
-
addSignature(
PdfSignatureRequest request) → Future< PdfSignatureRequest> -
Adds a signature to the document using the given
request. -
addSignatureForPage(
{required PdfPage page, required PdfSignatureSigner signer, required PdfSignatureBounds bounds, String fieldName = 'Signature1', String? reason, String? location, String? contactInfo, String? name, DateTime? signingTime, PdfSignatureAppearance? appearance, Widget? appearanceWidget, void drawAppearance(PdfGraphics graphics, PdfRect bounds)?, int? docMdpPermissionP, PdfTimestampProvider? timestampProvider, int contentsReserveSize = 16384, int byteRangeDigits = 10}) → Future< void> -
dispose(
) → void - Marks this instance as disposed and unusable.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
save(
) → Future< Uint8List> - Returns the current PDF bytes (including all signatures).
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited