PdfQuickInfo class
Fast checks without fully parsing the document structure.
Constructors
- PdfQuickInfo.fromBytes(Uint8List bytes)
-
factory
Properties
- docMdpPermissionP → int?
-
final
- hasEofMarker → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasPdfHeader → bool
-
final
- hasSignatures → bool
-
final
- isEncrypted → bool
-
final
- isPdf15OrAbove → bool
-
no setter
- pdfVersion → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited