PdfRsaPrivateKeySigner class
RSA private key signer for external signing APIs.
- Inheritance
-
- Object
- PdfExternalSigner
- PdfRsaPrivateKeySigner
Constructors
-
PdfRsaPrivateKeySigner({required RSAPrivateKey privateKey, required List<
Uint8List> certificates}) - Creates a signer from an RSA private key and certificate chain.
-
PdfRsaPrivateKeySigner.fromPem({required String privateKeyPem, required String certificatePem, List<
String> chainPem = const <String>[]}) -
Creates a signer from PEM-encoded key and certificates.
factory
Properties
-
certificates
→ List<
Uint8List> -
Returns the certificate chain as DER bytes.
no setteroverride
- digestAlgorithmOid → String
-
SignerInfo.digestAlgorithm OID.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- signatureAlgorithmOid → String
-
SignerInfo.signatureAlgorithm OID.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
signDigest(
Uint8List digest) → Future< Uint8List> -
Signs a digest using RSA/SHA-256.
override
-
signSignedAttributes(
Uint8List signedAttrsDer, Uint8List signedAttrsDigest) → Future< Uint8List> -
Optional hook for algorithms that sign signedAttrs bytes directly
(ex.: ECDSA/EdDSA em APIs que fazem hashing internamente).
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited