PdfSignatureBounds class
Signature rectangle description with a selectable coordinate system.
Constructors
- PdfSignatureBounds.pdf(PdfRect? rect)
- Creates bounds directly in PDF user space.
- PdfSignatureBounds.topLeft({required double left, required double top, required double width, required double height})
- Creates bounds using top-left coordinates.
Properties
- coordinateSystem → PdfCoordinateSystem
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- rect → PdfRect?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- topLeft → _TopLeftRect?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toPdfRect(
PdfPage page) → PdfRect -
Converts the bounds to a PDF-space rectangle for a given
page. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited