PdfSignatureCertificateInfo class
Constructors
-
PdfSignatureCertificateInfo({required String? subject, required String? issuer, required BigInt? serial, required DateTime? notBefore, required DateTime? notAfter, required List<
PdfSignatureOtherName> otherNames, required PdfSignatureIcpBrasilIds? icpBrasilIds}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- icpBrasilIds → PdfSignatureIcpBrasilIds?
-
final
- issuer → String?
-
final
- notAfter → DateTime?
-
final
- notBefore → DateTime?
-
final
-
otherNames
→ List<
PdfSignatureOtherName> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serial → BigInt?
-
final
- subject → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited