PdfSignatureConfig class
Metadata and configuration for external signatures.
Constructors
Properties
- contactInfo ↔ String?
-
Contact information.
getter/setter pair
- docMdpPermissionP ↔ int?
-
DocMDP permission value (1, 2, or 3).
getter/setter pair
- hasDocMdp → bool
-
Whether DocMDP permissions are configured.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDocTimeStamp ↔ bool
-
Whether this signature is a DocTimeStamp.
getter/setter pair
- location ↔ String?
-
Location of signing.
getter/setter pair
- name ↔ String?
-
Signer name.
getter/setter pair
- reason ↔ String?
-
Reason for signing.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- signingTime ↔ DateTime?
-
Signing time to embed.
getter/setter pair
- subFilter ↔ String?
-
SubFilter name (e.g. /adbe.pkcs7.detached).
getter/setter pair
Methods
-
configureDocMdpForFirstSignature(
PdfDocument document, {required int permissionP}) → void - Configures DocMDP for the first signature in a document.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited