PdfSignaturePreparedContext class
Properties
-
fieldByRange
→ Map<
String, PdfSignatureFieldInfo> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasSignatureContents → bool
-
final
- hasSignatureFields → bool
-
final
- pdfBytes → Uint8List
-
final
- quickInfo → PdfQuickInfo
-
final
-
ranges
→ List<
List< int> > -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
signatureContents
→ List<
Uint8List?> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
signatureContentsAt(
int index) → Uint8List? -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited