PdfSignatureSigner class
Wraps an external signer to be used by PDF signing APIs.
Constructors
- PdfSignatureSigner.external(PdfExternalSigner signer)
-
Wraps a custom external signer implementation.
factory
-
PdfSignatureSigner.pem({required String privateKeyPem, required X509Certificate certificate, List<
X509Certificate> chain = const <X509Certificate>[]}) -
factory
-
PdfSignatureSigner.raw({required String privateKeyPem, required String certificate, List<
String> chain = const <String>[]}) -
Creates a signer from PEM-encoded private key and certificate.
factory
Properties
- externalSigner → PdfExternalSigner
-
The underlying external signer instance.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromPkcs12Bytes(
{required Uint8List pkcs12Bytes, required String password, Pkcs12Decoder? decoder}) → Future< PdfSignatureSigner>