SpanningTableRow class
- Annotations
-
- @immutable
Constructors
-
SpanningTableRow({required List<
SpanningTableCell> children, bool repeat = false, BoxDecoration? decoration, TableCellVerticalAlignment? verticalAlignment}) -
const
Properties
-
children
→ List<
SpanningTableCell> -
final
- decoration → BoxDecoration?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- repeat → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- verticalAlignment → TableCellVerticalAlignment?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited